#include "wiced.h"
#include "Susi4.h"
#include "susi_i2c.h"

#define BUFF_128    128
#define I2C_RETRY   3


static wiced_i2c_device_t  i2cHandle[I2C_MAX_BUS];
static uint8_t  m_TxBuff[BUFF_128];
static bool g_bInited = false;

void SusiI2C_Init(void)
{
	if(!g_bInited) {
		int i;

		for(i=0;i<I2C_MAX_BUS;i++)
		{
            i2cHandle[i].port           = i;
            i2cHandle[i].address_width  = I2C_ADDRESS_WIDTH_7BIT;
            i2cHandle[i].flags          = I2C_DEVICE_NO_DMA;
            i2cHandle[i].speed_mode     = I2C_STANDARD_SPEED_MODE;         
		}
		g_bInited = true;
	}
}

/*****************************************************************************************************/
SusiStatus_t SUSI_API SusiI2CWriteReadCombine(
	SusiId_t Id,		/* IN		I2C Bus Id */
	uint8_t Addr,		/* IN		Encoded 7Bit I2C Device Address */
	uint8_t *pWBuffer,	/* INOPT	Write Data pBuffer */
	uint32_t WriteLen,	/* IN		Number of Bytes to write */
	uint8_t *pRBuffer,	/* OUTOPT	Read Data pBuffer */
	uint32_t ReadLen	/* IN		Number of Bytes to Read */
    )
{
    wiced_result_t result;
    wiced_i2c_message_t msg;

    if(Id >= I2C_MAX_BUS) return SUSI_STATUS_INVALID_PARAMETER;
	SusiI2C_Init();

    i2cHandle[Id].address=Addr;
	result=wiced_i2c_init(&i2cHandle[Id]);

    if(result != WICED_SUCCESS)
        return result;

    wiced_i2c_init_combined_message(&msg, pWBuffer, pRBuffer, WriteLen, ReadLen, I2C_RETRY, I2C_DEVICE_NO_DMA);
    result = wiced_i2c_transfer(&i2cHandle[Id], &msg, 1);

    if(result != WICED_SUCCESS)
        return result;

    return SUSI_STATUS_SUCCESS;
}

SusiStatus_t SUSI_API SusiI2CReadTransfer(
	SusiId_t Id,		/* IN	I2C Bus Id */
	uint32_t Addr,		/* IN	Encoded 7/10Bit I2C Device Address */
	uint32_t Cmd,		/* IN	I2C Command / Offset */
	uint8_t *pBuffer,	/* OUT	Transfer Data pBuffer */
	uint32_t ReadLen	/* IN	Byte Count to read */
    )
{
    wiced_result_t result;
    wiced_i2c_message_t msg[2];

    if(Id >= I2C_MAX_BUS) return SUSI_STATUS_INVALID_PARAMETER;
	SusiI2C_Init();

    i2cHandle[Id].address=Addr;
	result=wiced_i2c_init(&i2cHandle[Id]);
    if(result != WICED_SUCCESS)
        return result;

    wiced_i2c_init_tx_message(&msg[0], &Cmd, 1, I2C_RETRY, I2C_DEVICE_NO_DMA);
    wiced_i2c_init_rx_message(&msg[1], pBuffer, ReadLen, I2C_RETRY, I2C_DEVICE_NO_DMA);
    result = wiced_i2c_transfer(&i2cHandle[Id], msg, 2);

    if(result != WICED_SUCCESS)
        return result;

    return SUSI_STATUS_SUCCESS;
}

SusiStatus_t SUSI_API SusiI2CWriteTransfer(
	SusiId_t Id,		/* IN	I2C Bus Id */
	uint32_t Addr,		/* IN	Encoded 7/10Bit I2C Device Address */
	uint32_t Cmd,		/* IN	I2C Command / Offset */
	uint8_t *pBuffer,	/* IN	Transfer Data pBuffer */ 
	uint32_t ByteCnt	/* IN	Byte Count to write */
    )
{
    wiced_result_t result;
    wiced_i2c_message_t msg;

    if(Id >= I2C_MAX_BUS) return SUSI_STATUS_INVALID_PARAMETER;
	SusiI2C_Init();

    i2cHandle[Id].address=Addr;
	result=wiced_i2c_init(&i2cHandle[Id]);
    if(result != WICED_SUCCESS)
        return result;


	memset(m_TxBuff, 0, BUFF_128);
	m_TxBuff[0] = Cmd;
	if(ByteCnt<BUFF_128)
	{	
		memcpy(m_TxBuff+1, pBuffer, ByteCnt);
	}
	else
	{
		return SUSI_STATUS_INVALID_PARAMETER;
	}	
	
    wiced_i2c_init_tx_message(&msg, m_TxBuff, ByteCnt+1, I2C_RETRY, I2C_DEVICE_NO_DMA);
    result = wiced_i2c_transfer(&i2cHandle[Id], &msg, 1);

    if(result != WICED_SUCCESS)
        return result;

    return SUSI_STATUS_SUCCESS;
}



// Not support
SusiStatus_t SUSI_API SusiI2CProbeDevice(
	SusiId_t Id,		/* IN	I2C Bus Id */
	uint32_t Addr		/* IN	Encoded 7/10Bit I2C Device Address */
    )
{
    wiced_result_t result;

    if(Id >= I2C_MAX_BUS) return SUSI_STATUS_INVALID_PARAMETER;
	SusiI2C_Init();

    i2cHandle[Id].address=Addr;
	result=wiced_i2c_init(&i2cHandle[Id]);
    if(result != WICED_SUCCESS)
        return result;

    result=wiced_i2c_probe_device(&i2cHandle[Id], I2C_RETRY);

    if(result != WICED_SUCCESS)
        return result;

    return SUSI_STATUS_SUCCESS;

}	    


SusiStatus_t SUSI_API SusiI2CGetFrequency(
	SusiId_t Id,		/* IN	I2C Bus Id */
	uint32_t *pFreq		/* OUT	I2C Bus Frequency (KHz) */
	)
{	
	if(Id >= I2C_MAX_BUS) return SUSI_STATUS_INVALID_PARAMETER;
	
	SusiI2C_Init();

	if(i2cHandle[Id].speed_mode == I2C_LOW_SPEED_MODE)
		*pFreq = 10;
    else if(i2cHandle[Id].speed_mode == I2C_STANDARD_SPEED_MODE)
		*pFreq = 100;
    else if(i2cHandle[Id].speed_mode == I2C_HIGH_SPEED_MODE)
        *pFreq = 400;
    else
        return SUSI_STATUS_READ_ERROR;
	
	return SUSI_STATUS_SUCCESS;
}

SusiStatus_t SUSI_API SusiI2CSetFrequency(
	SusiId_t Id,		/* IN	I2C Bus Id */
	uint32_t Freq		/* IN	I2C Bus Frequency (KHz) */
	)
{
	if(Id >= I2C_MAX_BUS) return SUSI_STATUS_INVALID_PARAMETER;
	
	SusiI2C_Init();

    if(Freq==10)
        i2cHandle[Id].speed_mode = I2C_LOW_SPEED_MODE;
    else if(Freq==100)
        i2cHandle[Id].speed_mode = I2C_STANDARD_SPEED_MODE;
    else if(Freq==400)
        i2cHandle[Id].speed_mode = I2C_HIGH_SPEED_MODE;
    else
        return SUSI_STATUS_INVALID_PARAMETER;

    return SUSI_STATUS_SUCCESS;
}

